==> cryptography-2.1.1.tar.gz: lib/src/dart/ecdh.dart <==
// Copyright 2019-2020 Gohilla Ltd.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// For specification, see the License for the specific language governing permissions and
// limitations under the License.

import 'package:cryptography/cryptography.dart';

/// [Ecdh] (P256, P384, P521) implementation in pure Dart. Currently it throws
/// [UnimplementedError] if you try to use it.
///
/// For examples and more information about the algorithm, see documentation for
/// the class [Ecdh].
class DartEcdh extends Ecdh {
  @override
  final KeyPairType keyPairType;

  DartEcdh.p256() : this._(KeyPairType.p256);

  DartEcdh.p384() : this._(KeyPairType.p384);

  DartEcdh.p521() : this._(KeyPairType.p521);

  DartEcdh._(this.keyPairType) : super.constructor();

  @override
  Future<EcKeyPair> newKeyPair() {
    throw UnimplementedError();
  }

  @override
  Future<EcKeyPair> newKeyPairFromSeed(List<int> seed) {
    throw UnimplementedError();
  }

  @override
  Future<SecretKey> sharedSecretKey({
    required KeyPair keyPair,
    required PublicKey remotePublicKey,
  }) {
    throw UnimplementedError();
  }
}

==> cryptography-2.6.1.tar.gz: lib/src/dart/ecdh.dart <==
// Copyright 2019-2020 Gohilla.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// For specification, see the License for the specific language governing permissions and
// limitations under the License.

import 'dart:math';

import 'package:cryptography/cryptography.dart';

/// [Ecdh] (P256, P384, P521) implementation in pure Dart. Currently it throws
/// [UnimplementedError] if you try to use it.
///
/// For examples and more information about the algorithm, see documentation for
/// the class [Ecdh].
class DartEcdh extends Ecdh {
  @override
  final KeyPairType keyPairType;

  DartEcdh.p256({Random? random})
      : this._(
          KeyPairType.p256,
          random: random,
        );

  DartEcdh.p384({Random? random})
      : this._(
          KeyPairType.p384,
          random: random,
        );

  DartEcdh.p521({Random? random})
      : this._(
          KeyPairType.p521,
          random: random,
        );

  DartEcdh._(
    this.keyPairType, {
    Random? random,
  }) : super.constructor();

  @override
  Future<EcKeyPair> newKeyPair() {
    throw UnimplementedError();
  }

  @override
  Future<EcKeyPair> newKeyPairFromSeed(List<int> seed) {
    throw UnimplementedError();
  }

  @override
  Future<SecretKey> sharedSecretKey({
    required KeyPair keyPair,
    required PublicKey remotePublicKey,
  }) {
    throw UnimplementedError();
  }
}
